Documentation
¶
Index ¶
- Variables
- func CleanFileName(fileName string) string
- func SimpleExtract(params *SimpleExtractParams) (*savior.ExtractorResult, error)
- type ArchiveInfo
- type ArchiveStrategy
- type Contents
- type EntriesLister
- type Entry
- type ExtractParams
- type LoadFunc
- type SaveFunc
- type SimpleExtractParams
- type StageTwoStrategy
- type ThrottledSaveFunc
- type TryOpenParams
Constants ¶
This section is empty.
Variables ¶
var (
ErrUnrecognizedArchiveType = errors.New("Unrecognized archive type")
)
Functions ¶
func CleanFileName ¶
func SimpleExtract ¶
func SimpleExtract(params *SimpleExtractParams) (*savior.ExtractorResult, error)
Types ¶
type ArchiveInfo ¶
type ArchiveInfo struct {
Strategy ArchiveStrategy
Features savior.ExtractorFeatures
Format string
StageTwoStrategy StageTwoStrategy
PostExtract []string
}
func Probe ¶
func Probe(params *TryOpenParams) (*ArchiveInfo, error)
func (*ArchiveInfo) ApplyStageTwo ¶
func (ai *ArchiveInfo) ApplyStageTwo(consumer *state.Consumer, aRes *savior.ExtractorResult, installFolder string) (*savior.ExtractorResult, error)
func (*ArchiveInfo) GetExtractor ¶
type ArchiveStrategy ¶
type ArchiveStrategy int
const ( ArchiveStrategyNone ArchiveStrategy = 0 ArchiveStrategyZip ArchiveStrategy = 100 ArchiveStrategyTar ArchiveStrategy = 200 ArchiveStrategyTarGz ArchiveStrategy = 201 ArchiveStrategyTarBz2 ArchiveStrategy = 202 ArchiveStrategyTarXz ArchiveStrategy = 203 ArchiveStrategySevenZip ArchiveStrategy = 300 )
func (ArchiveStrategy) String ¶
func (as ArchiveStrategy) String() string
type EntriesLister ¶
type ExtractParams ¶
type SimpleExtractParams ¶
type StageTwoStrategy ¶
type StageTwoStrategy int
const ( StageTwoStrategyNone StageTwoStrategy = 0 StageTwoStrategyMojoSetup StageTwoStrategy = 666 )
func (StageTwoStrategy) String ¶
func (sts StageTwoStrategy) String() string
type ThrottledSaveFunc ¶
Saves the state if force is true or the interval has passed Returns true if the state was actually saved, false if not
func ThrottledSave ¶
func ThrottledSave(params *ExtractParams) ThrottledSaveFunc
type TryOpenParams ¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.